"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getQuestions = getQuestions;
const inquirer_common_1 = require("@sap-ux/inquirer-common");
const i18n_1 = require("../i18n");
const types_1 = require("../types");
const validators = __importStar(require("./validators"));
const btp_utils_1 = require("@sap-ux/btp-utils");
const prompt_helpers_1 = require("./prompt-helpers");
/**
 * Retrieves the prompt configuration for selecting a Cloud Foundry destination name.
 *
 * This function generates a prompt that allows users to specify a destination name. The prompt can be rendered as a list or
 * an input field depending on the provided options. If the environment supports
 * autocomplete, it can provide suggestions based on existing destinations.
 *
 * @param {DestinationNamePromptOptions} destinationOptions - The options for configuring
 *        the destination name prompt.
 * @param {string} destinationOptions.destination - The Cloud Foundry destination name
 *        to be used.
 * @param {string} destinationOptions.defaultValue - The default destination value for CF.
 * @param {boolean} [destinationOptions.addDestinationHintMessage] - A flag to indicate
 *        whether to show a hint for the destination name.
 * @param {CfSystemChoice[]} [destinationOptions.additionalChoiceList] - Additional choices
 *        available for the destination. If additional choices are provided and the environment is VsCode, the prompt
 *        type will render as a list instead of an input field.
 * @param {boolean} [destinationOptions.useAutocomplete] - A flag to indicate whether
 *        to use an autocomplete feature for the destination name input.
 * @param {boolean} [destinationOptions.addBTPDestinationList] - A flag to indicate whether to include BTP destination choices.
 * @returns {Promise<CfDeployConfigQuestions>} A promise that resolves to the configuration
 *          of the prompt, which includes the question and any related options for rendering
 *          the prompt in a user interface.
 */
async function getDestinationNamePrompt(destinationOptions) {
    const { hint = false, additionalChoiceList = [], defaultValue, useAutocomplete = false, addBTPDestinationList = true } = destinationOptions;
    const isBAS = (0, btp_utils_1.isAppStudio)();
    const destinations = addBTPDestinationList ? await (0, prompt_helpers_1.fetchBTPDestinations)() : {};
    const destinationList = [...additionalChoiceList, ...(await (0, prompt_helpers_1.getCfSystemChoices)(destinations))];
    // If BAS is used or additional choices are provided, the prompt should be a list
    // If VsCode is used and additional choices are not provided, the prompt should be an input field
    // If VsCode is used and additional choices are provided, the prompt should be a list
    const basePromptType = isBAS || additionalChoiceList.length ? 'list' : 'input';
    // If autocomplete is enabled and there are destination choices, the prompt should be an autocomplete
    const promptType = useAutocomplete && destinationList.length ? 'autocomplete' : basePromptType;
    return {
        guiOptions: {
            mandatory: !isBAS,
            breadcrumb: (0, i18n_1.t)('prompts.destinationNameMessage')
        },
        type: promptType,
        default: () => defaultValue,
        name: types_1.promptNames.destinationName,
        message: () => (hint ? (0, i18n_1.t)('prompts.directBindingDestinationHint') : (0, i18n_1.t)('prompts.destinationNameMessage')),
        validate: (destination) => {
            return validators.validateDestinationQuestion(destination, !destination && isBAS);
        },
        source: (prevAnswers, input) => (0, inquirer_common_1.searchChoices)(input, destinationList),
        choices: () => destinationList
    };
}
/**
 * Creates a prompt for managing application router during cf deployment.
 *
 *
 * This function returns a confirmation question that asks whether to add a managed application router
 * to the cf deployment. The prompt only appears if no mta file is found.
 *
 * @returns {ConfirmQuestion<CfDeployConfigAnswers>} Returns a confirmation question object for configuring the application router.
 */
function getAddManagedRouterPrompt() {
    return {
        type: 'confirm',
        name: types_1.promptNames.addManagedAppRouter,
        guiOptions: {
            breadcrumb: (0, i18n_1.t)('prompts.addApplicationRouterBreadcrumbMessage')
        },
        message: () => (0, i18n_1.t)('prompts.generateManagedApplicationToRouterMessage'),
        default: () => true
    };
}
/**
 *
 * @returns A confirmation question object which overwrites destination.
 */
function getOverwritePrompt() {
    return {
        type: 'confirm',
        name: types_1.promptNames.overwrite,
        guiOptions: {
            hint: (0, i18n_1.t)('prompts.overwriteHintMessage')
        },
        default: () => {
            return true;
        },
        message: () => (0, i18n_1.t)('prompts.overwriteMessage')
    };
}
/**
 * Retrieves a list of deployment questions based on the application root and prompt options.
 *
 * @param {CfDeployConfigPromptOptions} promptOptions - The configuration options for prompting during cf target deployment.
 * @param {Logger} [log] - The logger instance to use for logging.
 * @returns {CfDeployConfigQuestions[]} Returns an array of questions related to cf deployment configuration.
 */
async function getQuestions(promptOptions, log) {
    const destinationOptions = promptOptions[types_1.promptNames.destinationName];
    const addOverwriteQuestion = promptOptions[types_1.promptNames.overwrite] ?? false;
    const addManagedAppRouter = promptOptions[types_1.promptNames.addManagedAppRouter] ?? false;
    const questions = [];
    // Collect questions into an array
    questions.push(await getDestinationNamePrompt(destinationOptions));
    if (addManagedAppRouter) {
        log?.info((0, i18n_1.t)('info.addManagedAppRouter'));
        questions.push(getAddManagedRouterPrompt());
    }
    if (addOverwriteQuestion) {
        log?.info((0, i18n_1.t)('info.overwriteDestination'));
        questions.push(getOverwritePrompt());
    }
    return questions;
}
//# sourceMappingURL=prompts.js.map